This crate contains kube-rs compatible bindings for Kubernetes custom resources for the control.k8ssandra.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
control.k8ssandra.io/v1alpha1
CassandraTask